@@ -9,7 +9,7 @@ import gzip
 import gtfparse
 import pandas as pd
 from Bio import SeqIO
-from Bio.Alphabet import generic_dna
+#from Bio.Alphabet import generic_dna
 
 
 class ReadAnnotations(object):
@@ -44,6 +44,12 @@ class ReadAnnotations(object):
 
         self.annot = pd.read_table(cached_gtf, sep='\t', low_memory=False)
 
+        # 2020-11-06 if Gencode GTF is used, column is transcript_type rather than transcript_biotype.
+        # This will make the transcript_biotype column manually
+
+        if not 'transcript_biotype' in self.annot.columns:
+            self.annot['transcript_biotype'] = self.annot['transcript_type']
+
         return True
 
 
@@ -72,12 +78,12 @@ class ReadGenome(object):
 
         if self.f_loc.endswith('.gz'):
             with gzip.open(self.f_loc, 'rt') as f:
-                self.genome = SeqIO.to_dict(SeqIO.parse(f, 'fasta', generic_dna))
+                self.genome = SeqIO.to_dict(SeqIO.parse(f, 'fasta'))
                 self.logger.info('Read from zipped genome. \n\n')
 
         else:
             with open(self.f_loc, 'rt') as f:
-                self.genome = SeqIO.to_dict(SeqIO.parse(f, 'fasta', generic_dna))
+                self.genome = SeqIO.to_dict(SeqIO.parse(f, 'fasta'))
                 self.logger.info('Read from genome. \n\n')
 
         return True
